pygeodesy.utm.UTMError

Package pygeodesy :: Module utm :: Class UTMError |
[frames] | no frames]

# Class UTMError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                   exceptions.ValueError --+
                                           |
                          errors._ValueError --+
                                               |
                                              UTMError

Known Subclasses:
  - etm.ETMError

Universal Transverse Mercator (UTM parse or other Utm issue.

Instance Methods
Inherited from `errors._ValueError`: `__init__` Inherited from `exceptions.ValueError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`